==> kwayland-5.73.0-1-armv6h.pkg.tar.xz: usr/include/KF5/KWayland/Client/kwaylandclient_export.h <==

#ifndef KWAYLANDCLIENT_EXPORT_H
#define KWAYLANDCLIENT_EXPORT_H

#ifdef KWAYLANDCLIENT_STATIC_DEFINE
#  define KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_NO_EXPORT
#else
#  ifndef KWAYLANDCLIENT_EXPORT
#    ifdef KF5WaylandClient_EXPORTS
        /* We are building this library */
#      define KWAYLANDCLIENT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KWAYLANDCLIENT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KWAYLANDCLIENT_NO_EXPORT
#    define KWAYLANDCLIENT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED
#  define KWAYLANDCLIENT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT
#  define KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT
#  define KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KWAYLANDCLIENT_NO_DEPRECATED
#    define KWAYLANDCLIENT_NO_DEPRECATED
#  endif
#endif

#define KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KWAYLANDCLIENT_NO_DEPRECATED) && !defined(KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KWAYLANDCLIENT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS) && !defined(KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KWAYLANDCLIENT_NO_DEPRECATED)
#  undef KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT
#elif defined(KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS)
#  define KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT
#else
#  define KWAYLANDCLIENT_DEPRECATED KWAYLANDCLIENT_DECL_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KWAYLANDCLIENT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KWAYLANDCLIENT_NO_DEPRECATED
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54900
#endif
#ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
#  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE
#  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54900
#  endif
#endif

#ifndef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53100
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_49(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_49(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53200
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_50(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_50(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53400
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_52(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_52(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53500
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_53(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_53(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x54900
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text)
#endif
#define KWAYLANDCLIENT_DEPRECATED_VERSION_5(minor, text)      KWAYLANDCLIENT_DEPRECATED_VERSION_5_##minor(text)
#define KWAYLANDCLIENT_DEPRECATED_VERSION(major, minor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KWAYLANDCLIENT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KWAYLANDCLIENT_EXPORT_H */

==> kwayland-5.75.0-1-armv6h.pkg.tar.xz: usr/include/KF5/KWayland/Client/kwaylandclient_export.h <==

#ifndef KWAYLANDCLIENT_EXPORT_H
#define KWAYLANDCLIENT_EXPORT_H

#ifdef KWAYLANDCLIENT_STATIC_DEFINE
#  define KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_NO_EXPORT
#else
#  ifndef KWAYLANDCLIENT_EXPORT
#    ifdef KF5WaylandClient_EXPORTS
        /* We are building this library */
#      define KWAYLANDCLIENT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KWAYLANDCLIENT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KWAYLANDCLIENT_NO_EXPORT
#    define KWAYLANDCLIENT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED
#  define KWAYLANDCLIENT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT
#  define KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED
#endif

#ifndef KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT
#  define KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KWAYLANDCLIENT_NO_DEPRECATED
#    define KWAYLANDCLIENT_NO_DEPRECATED
#  endif
#endif

#define KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KWAYLANDCLIENT_NO_DEPRECATED) && !defined(KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KWAYLANDCLIENT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS) && !defined(KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KWAYLANDCLIENT_NO_DEPRECATED)
#  undef KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT
#elif defined(KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS)
#  define KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_NO_EXPORT
#else
#  define KWAYLANDCLIENT_DEPRECATED KWAYLANDCLIENT_DECL_DEPRECATED
#  define KWAYLANDCLIENT_DEPRECATED_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED_EXPORT
#  define KWAYLANDCLIENT_DEPRECATED_NO_EXPORT KWAYLANDCLIENT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KWAYLANDCLIENT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KWAYLANDCLIENT_NO_DEPRECATED
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54b00
#endif
#ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
#  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE
#  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54b00
#  endif
#endif

#ifndef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KWAYLANDCLIENT_DEPRECATED
#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53100
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_49(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_49(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53200
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_50(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_50(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53400
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_52(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_52(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x53500
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_53(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_53(text)
#endif

#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x54900
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
#else
#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text)
#endif
#define KWAYLANDCLIENT_DEPRECATED_VERSION_5(minor, text)      KWAYLANDCLIENT_DEPRECATED_VERSION_5_##minor(text)
#define KWAYLANDCLIENT_DEPRECATED_VERSION(major, minor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KWAYLANDCLIENT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)

#endif /* KWAYLANDCLIENT_EXPORT_H */
